1) make calculation accept intrest as Series

2) generation tables

3) more Pythonic imports

4) cashflows should not depend on intrest

5) clean up code:
* smarter read of adjustments
* get rid of 'payments'
* do not dictify adjustments?

6) centralize checks in check func

7) improve performance

8) make package to be imported in notebook import factors as fs
